;;; --------------------------------------------------------------------------
;;; File     : DDEdAcad.lsp
;;; Purpose  : To provide auto-loading of DDEDTEXT, DDEDONE, DE & D1 commands,
;;;            (naus_dded*) and (naus_lisped) functions, and toolbar menu if
;;;            appropriate.
;;;            Load this file at startup time, e.g. from ACAD.LSP or
;;;            ACADDOC.LSP.
;;; Note     : To prevent the toolbar menu loading, search for ** in this file.
;;; Version  : 4.03
;;; Date     : 6 January 2000
;;; --------------------------------------------------------------------------

(princ "\nDDEdText 4.03 ")

(if (not C:DDEDTEXT)
  (progn  ; Only define all these functions if it's not already done


;; ---------------------------------------------------------------------------
;; Function : C:DDEDTEXT
;; Purpose  : Auto-loading stub for (C:DDEDTEXT)
;; ---------------------------------------------------------------------------

    (defun C:DDEDTEXT ()
      (naus_ddedload)
      (C:DDEDTEXT)
    ) ; End C:DDEDTEXT (stub)

;; ---------------------------------------------------------------------------
;; Function : C:DDEDONE
;; Purpose  : Auto-loading stub for (C:DDEDONE)
;; ---------------------------------------------------------------------------

    (defun C:DDEDONE ()
      (naus_ddedload)
      (C:DDEDONE)
    ) ; End C:DDEDONE (stub)

;; ---------------------------------------------------------------------------
;; Function : naus_lisped
;; Purpose  : Auto-loading stub for (naus_lisped)
;; ---------------------------------------------------------------------------

    (defun naus_lisped (STRING)
      (naus_ddedload)
      (naus_lisped STRING)
    )

;; ---------------------------------------------------------------------------
;; Function : naus_ddedss
;; Purpose  : Auto-loading stub for (naus_ddedss)
;; ---------------------------------------------------------------------------

    (defun naus_ddedss (SS)
      (naus_ddedload)
      (naus_ddedss SS)
    )

;; ---------------------------------------------------------------------------
;; Function : C:DE
;; Purpose  : Short-form version of DDEDTEXT command
;; ---------------------------------------------------------------------------

    (defun C:DE () (C:DDEDTEXT))

;; ---------------------------------------------------------------------------
;; Function : C:D1
;; Purpose  : Short-form version of DDEDONE command
;; ---------------------------------------------------------------------------

    (defun C:D1 () (C:DDEDONE))

;; ---------------------------------------------------------------------------
;; Function : naus_ddedpath
;; Purpose  : Returns a file path which allows for the use of one of the
;;            NAUS-DDEDPREFIX or NAUS-ALLPREFIX global variables, or the
;;            DDEDTEXT or CAD-NAUSEAM OS variables.
;; ---------------------------------------------------------------------------

    (defun naus_ddedpath (FNAME / prefix)
      (strcat
        (cond
          (NAUS-DDEDPREFIX NAUS-DDEDPREFIX)
          (NAUS-ALLPREFIX NAUS-ALLPREFIX)
          ((setq prefix (getenv "DDEDTEXT")) prefix)
          ((setq prefix (getenv "CAD-NAUSEAM")) prefix)
          (T "")
        )
        FNAME
      )
    ) ; End naus_ddedpath

;; ---------------------------------------------------------------------------
;; Function : naus_ddedload
;; Purpose  : Loads either the registered version of DDEDTEXT or, if not
;;            available, the unregistered version.
;; ---------------------------------------------------------------------------

    (defun naus_ddedload ()
      (if (= 'failed (load (naus_ddedpath "DDEDREG") 'failed))
        (if (= 'failed (load (naus_ddedpath "DDEDTEXT") 'failed))
          (alert "Cannot load AutoLISP file for DDEDTEXT")
        )
      )
    ) ; End naus_ddedload

;; ---------------------------------------------------------------------------
;; Function : naus_ddedloadmenu
;; Purpose  : Loads the DDEDTEXT toolbar menu
;; ---------------------------------------------------------------------------

    (defun naus_ddedloadmenu (/ loadmenu)
      (naus_load_toolbar_menu
        (naus_ddedpath
          (strcat
            "DDED"
            (if (wcmatch (getvar "ACADVER") "*13*") "TE13" "TEXT")
          )
        )
        "DDEDTEXT"
        "ID_DDEdPop01"
      )
      (princ)
    ) ; End naus_ddedloadmenu

;; ---------------------------------------------------------------------------
;; Function : naus_load_toolbar_menu
;; Purpose  : Loads a toolbar menu
;; ---------------------------------------------------------------------------

    (defun naus_load_toolbar_menu (FNAME MGROUP ID / cmdecho)
      (if
        (and
          (wcmatch (getvar "PLATFORM") "*Windows*")
          (wcmatch (getvar "ACADVER") "*13*,*14*,*15*,*16*")
        )
        (progn
          (if (wcmatch (getvar "ACADVER") "*13*")
            (while (not (menucmd "P1.1=?"))) ; Wait for menu before acting
          )
          (if (not (menucmd (strcat "G" MGROUP "." ID "=?")))
            (progn
              (setq cmdecho (getvar "CMDECHO"))
              (setvar "CMDECHO" 0)
              (command)
              (command "_.MENULOAD" FNAME)
              (setvar "CMDECHO" cmdecho)
            )
          )
        ) ; End progn
        (princ (strcat "\nWARNING: Can't load toolbar menu " FNAME ". "))
      )
      (princ)
    ) ; End naus_load_toolbar_menu

;; ---------------------------------------------------------------------------
;; Function : naus_startup_add
;; Purpose  : Adds some code to the S::STARTUP function
;; ---------------------------------------------------------------------------

    (defun naus_startup_add (CODE / # funcname)
      (cond                             ; What is S::STARTUP?
        ((not S::STARTUP)               ; It's not defined yet
         (setq S::STARTUP (list nil CODE)) ; So make it the code passed in
        )
        ((listp S::STARTUP)             ; It's a list-based function
         (if (not (member CODE S::STARTUP)) ; Make sure we don't re-add code
           (setq S::STARTUP (append S::STARTUP (list CODE))) ; Add code
         )
        )
        (T                              ; It must be a subr or exsubr or usubr
         (setq # 0)
         (while                         ; Find unused NAUS_OLD_STARTUP_n symbol
           (eval
             (setq
               funcname
                (read (strcat "NAUS_OLD_STARTUP_" (itoa (setq # (1+ #)))))
             )
           )
         )
         (set funcname S::STARTUP)      ; (setq OLD_STARTUP_n S::STARTUP)
         (setq S::STARTUP (list nil (list funcname) CODE)) ; Make S::STARTUP
        )
      )
    ) ; End naus_startup_add


;; ---------------------------------------------------------------------------
;; We've finished defining functions, so now we can actually do stuff.
;; ---------------------------------------------------------------------------

;; ** User-modifiable code
;;    If you do not wish to load the toolbar menu, place a single semi-colon
;;    (;) at the start of the next line
    (naus_startup_add '(naus_ddedloadmenu)) ; Add menu load call to S::STARTUP

    (if vl-doc-import ; Export global variables (only relevant in vlisp)
      (foreach one
       '(naus_ddedload         naus_ddedpath
         naus_lisped           naus_ddedss)
        (vl-doc-import one)
      )
    )
    (princ "autoloaded. ")

  ) ; End progn
  (princ "already loaded. ") ; Display if 2nd attempt at loading is made.
) ; End if (not C:DDEDTEXT)

(princ)

;;; --------------------------------------------------------------------------
;;; End DDEdAcad.lsp
;;; --------------------------------------------------------------------------