//// -------------------------------------------------------------------------
//// File     : DDEdText.dcl
//// Copyright: cad nauseam, 1997-1999.  Shareware, NOT freeware.
////            All rights reserved.
//// Author   : Steve Johnson
//// Purpose  : Dialogue box definition for DDEdText and DDEdOne commands
////            when editing text, dimension, rtext and mtext entities.
//// Notes    : User-modifiable items are indicated with **
//// Version  : 4.02
//// Date     : 14 December 1999
//// -------------------------------------------------------------------------


/// --------------------------------------------------------------------------
/// Turn off error checking
/// --------------------------------------------------------------------------

dcl_settings : default_dcl_settings { audit_level = 0; }


/// --------------------------------------------------------------------------
/// Widget: ddedtext
/// This is the main dialogue box.
/// --------------------------------------------------------------------------

ddedtext : dialog {
  key                   = "title";
  initial_focus         = "text";
  dded_buttons;
  insert_row_2;

// ---------------------------------------------------------------------------
// ** To add extra rows of buttons, remove the double slashes // from the
// start of one or both of the next two lines:
//  insert_row_3;
//  insert_row_4;
// You can modify the contents of these rows. See insert_row_2 to
// insert_row_4 below.
// ---------------------------------------------------------------------------

  current_row;
  edit_row;
  spacer;
  full_ok_cancel;
} // end ddedtext


/// --------------------------------------------------------------------------
/// Widget: dded_buttons
/// Row of buttons above text.
/// --------------------------------------------------------------------------

dded_buttons : row {
  alignment             = centered;
  : fixed_button {
    label               = "Flip Case";
    key                 = "case";
  }

// ---------------------------------------------------------------------------
// ** The following 3 buttons can be modified, as described in DDEDTEXT.TXT
  : fixed_button {
    key                 = "insert_1";
    label               = "Degrees";
    mtext_string        = "%%d";
    text_string         = "%%d";
    replace_all         = false;
    at_start            = false;
    is_lisp             = false;
  }
  : fixed_button {
    key                 = "insert_2";
    label               = "Diameter";
    mtext_string        = "%%c";
    text_string         = "%%c";
    replace_all         = false;
    at_start            = true;
    is_lisp             = false;
  }
  : fixed_button {
    key                 = "insert_3";
    label               = "+/-";
    mtext_string        = "%%p";
    text_string         = "%%p";
    replace_all         = false;
    at_start            = false;
    is_lisp             = false;
}
  : fixed_button {
    label               = "User...";
    key                 = "user";
  }
// ---------------------------------------------------------------------------

} // end dded_buttons


/// --------------------------------------------------------------------------
/// Widgets: insert_row_2, insert_row_3 and insert_row_4
/// ** Extra rows of buttons which can be used to provide instant access to
/// user-defined insert strings.  See DDEdText.doc for details of how to
/// change the buttons.
/// --------------------------------------------------------------------------

insert_row_2 : row {
  alignment             = centered;
  : fixed_button {
    key                 = "insert_6";
    label               = "Clear";
    mtext_string        = "";
    text_string         = "";
    replace_all         = true;
    at_start            = false;
    is_lisp             = false;
  }
  : fixed_button {
    key                 = "insert_7";
    label               = "Short date";
    mtext_string        = "(naus_date_today \"D Mmm YY\")";
    text_string         = "(naus_date_today \"D Mmm YY\")";
    replace_all         = true;
    at_start            = false;
    is_lisp             = true;
  }
  : fixed_button {
    key                 = "insert_8";
    label               = "Long date";
    mtext_string        = "(naus_date_today \"Dddd Mmmm D, YYYY\")";
    text_string         = "(naus_date_today \"Dddd Mmmm D, YYYY\")";
    replace_all         = false;
    at_start            = false;
    is_lisp             = true;
  }
  : fixed_button {
    key                 = "insert_9";
    label               = "DWG name";
    mtext_string        = "(naus_dded_dwgname)";
    text_string         = "(naus_dded_dwgname)";
    replace_all         = false;
    at_start            = false;
    is_lisp             = true;
  }
  : fixed_button {
    key                 = "insert_10";
    label               = "Pick file...";
    mtext_string        = "(getfiled \"Pick file\" \"\" \"\" 32)";
    text_string         = "(getfiled \"Pick file\" \"\" \"\" 32)";
    replace_all         = true;
    at_start            = false;
    is_lisp             = true;
  }
} // end insert_row_2


insert_row_3 : row {
  alignment             = centered;
  : fixed_button {
    key                 = "insert_11";
    label               = "Insert 11";
    mtext_string        = "11";
    text_string         = "11";
    replace_all         = false;
    at_start            = false;
    is_lisp             = false;
  }
  : fixed_button {
    key                 = "insert_12";
    label               = "Insert 12";
    mtext_string        = "12";
    text_string         = "12";
    replace_all         = false;
    at_start            = false;
    is_lisp             = false;
  }
  : fixed_button {
    key                 = "insert_13";
    label               = "Insert 13";
    mtext_string        = "13";
    text_string         = "13";
    replace_all         = false;
    at_start            = false;
    is_lisp             = false;
  }
  : fixed_button {
    key                 = "insert_14";
    label               = "Insert 14";
    mtext_string        = "14";
    text_string         = "14";
    replace_all         = false;
    at_start            = false;
    is_lisp             = false;
  }
  : fixed_button {
    key                 = "insert_15";
    label               = "Insert 15";
    mtext_string        = "15";
    text_string         = "15";
    replace_all         = false;
    at_start            = false;
    is_lisp             = false;
  }
} // end insert_row_3


insert_row_4 : row {
  alignment             = centered;
  : fixed_button {
    key                 = "insert_16";
    label               = "Insert 16";
    mtext_string        = "16";
    text_string         = "16";
    replace_all         = false;
    at_start            = false;
    is_lisp             = false;
  }
  : fixed_button {
    key                 = "insert_17";
    label               = "Insert 17";
    mtext_string        = "17";
    text_string         = "17";
    replace_all         = false;
    at_start            = false;
    is_lisp             = false;
  }
  : fixed_button {
    key                 = "insert_18";
    label               = "Insert 18";
    mtext_string        = "18";
    text_string         = "18";
    replace_all         = false;
    at_start            = false;
    is_lisp             = false;
  }
  : fixed_button {
    key                 = "insert_19";
    label               = "Insert 19";
    mtext_string        = "19";
    text_string         = "19";
    replace_all         = false;
    at_start            = false;
    is_lisp             = false;
  }
  : fixed_button {
    key                 = "insert_20";
    label               = "Insert 20";
    mtext_string        = "20";
    text_string         = "20";
    replace_all         = false;
    at_start            = false;
    is_lisp             = false;
  }
} // end insert_row_4


/// --------------------------------------------------------------------------
/// Widget: current_row
/// --------------------------------------------------------------------------

current_row : row {
  : text {
    label               = "Current:";
    width               = 11;
    fixed_width         = true;
  }
  : text {
    key                 = "original";
    alignment           = left;
    width               = 80;
    fixed_width         = false;
  }
} // end current_row


/// --------------------------------------------------------------------------
/// Widget: edit_row
/// --------------------------------------------------------------------------

edit_row : row {
  : text {
    label               = "Edited:";
    width               = 12 ;
    fixed_width         = true;
  }
  : edit_box {
    label               = "";
    key                 = "text";
    edit_width          = 80;
    edit_limit          = 250;
    fixed_width         = false;
    allow_accept        = true;
  }
} // end edit_row


/// --------------------------------------------------------------------------
/// Widget: full_button
/// --------------------------------------------------------------------------

full_button : fixed_retirement_button {
  label                 = "Full editor...";
  key                   = "full";
} // end full_button


/// --------------------------------------------------------------------------
/// Widget: properties_button
/// --------------------------------------------------------------------------

properties_button : fixed_retirement_button {
  label                 = "Properties...";
  key                   = "properties";
} // end properties_button


/// --------------------------------------------------------------------------
/// Widget: reset_button
/// --------------------------------------------------------------------------

reset_button : fixed_retirement_button {
  label                 = "Reset";
  key                   = "reset";
} // end reset_button


/// --------------------------------------------------------------------------
/// Widget: cancel
/// --------------------------------------------------------------------------

cancel : fixed_retirement_button {
  label                 = "Cancel";
  key                   = "cancel";
  is_cancel             = true;
} // end cancel


/// --------------------------------------------------------------------------
/// Widget: cancel_all
/// --------------------------------------------------------------------------

cancel_all : fixed_retirement_button {
  label                 = "Cancel all";
  key                   = "finish";
} // end cancel_all


/// --------------------------------------------------------------------------
/// Widget: ok
/// --------------------------------------------------------------------------

ok : fixed_retirement_button {
  label                 = "OK";
  key                   = "accept";
  is_default            = true;
} // end ok


/// --------------------------------------------------------------------------
/// Widget: full_ok_cancel
/// --------------------------------------------------------------------------

full_ok_cancel : column {
  : row {
    alignment           = centered;

// ---------------------------------------------------------------------------
// ** Release 12 users may wish to remove the "Full editor..." button.
// To do this, place double slashes // at the start of the next two lines.
    full_button;
// ---------------------------------------------------------------------------

    properties_button;
    reset_button;
    ok;
    cancel;
    cancel_all;
  }
} // end full_ok_cancel


/// --------------------------------------------------------------------------
/// Widget: fixed_button
/// --------------------------------------------------------------------------

fixed_button : button {
// ---------------------------------------------------------------------------
// ** If you are trying to squeeze a lot of insert_N buttons onto a row, then
// reducing the width value below will help.
  width                 = 18;
// ---------------------------------------------------------------------------
  fixed_width           = true;
} // end fixed_button
  

/// --------------------------------------------------------------------------
/// Widget: fixed_retirement_button
/// --------------------------------------------------------------------------

fixed_retirement_button : retirement_button {
  width                 = 14;
  fixed_width           = true;
} // end fixed_retirement_button
  

/// --------------------------------------------------------------------------
/// Widget: list_user
/// This is a sub dialogue box used to list the user-defined insert strings.
/// --------------------------------------------------------------------------

list_user : dialog {
  label                 = "User Text to Insert";
  : list_box {
    key                 = "list_box";
    at_start            = false;
    width               = 100;
    height              = 28;
  }
  ok_cancel;
} // end list_user


//// -------------------------------------------------------------------------
//// End DDEDTEXT.DCL
//// -------------------------------------------------------------------------